@@ -6,14 +6,16 @@ package Dist::Zilla::Plugin::Author::CSSON::GithubActions::BaseWorkflow;
 
 # ABSTRACT: An example Github Actions workflow
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moose;
 with qw/
     Dist::Zilla::Plugin::Author::CSSON::GithubActions::Role::Workflow
 /;
 
-sub filepath { 'share/base-workflow.yml' }
+sub main_module { 'Dist::Zilla::Plugin::Author::CSSON::GithubActions' }
+
+sub filepath { 'base-workflow.yml' }
 
 1;
 
@@ -29,7 +31,7 @@ Dist::Zilla::Plugin::Author::CSSON::GithubActions::BaseWorkflow - An example Git
 
 =head1 VERSION
 
-Version 0.0100, released 2020-12-25.
+Version 0.0101, released 2020-12-25.
 
 =head1 SYNOPSIS
 
